@@ -417,8 +417,8 @@ class MutationRoot:
 
         return wrapById(res, wrapper)
 
-    def create_boolean_variable(self, user_permission, name, thingId=undefined, developer_only=undefined,  value=undefined, index=undefined):
-        thingId_arg = parse_arg("thingId", thingId)
+    def create_boolean_variable(self, user_permission, name, thing_id=undefined, developer_only=undefined,  value=undefined, index=undefined):
+        thingId_arg = parse_arg("thingId", thing_id)
         user_permission_arg = parse_arg(
             "userPermission", user_permission, is_enum=True)
         name_arg = parse_arg("name", name)
